@@ -4,8 +4,6 @@ import importlib
 import os
 import re
 import sys
-import tempfile
-from contextlib import suppress
 from io import StringIO
 from pathlib import Path
 from typing import List, Optional, Pattern
@@ -140,7 +138,8 @@ def check_dependencies(ctx):
     importlib.invalidate_caches()
 
     # reload original, unpatched safety
-    from safety.formatter import report
+    from safety.formatter import SafetyFormatter
+    from safety.safety import calculate_remediations
     from safety.safety import check as safety_check
     from safety.util import read_requirements
 
@@ -154,10 +153,19 @@ def check_dependencies(ctx):
     # check using safety as a library
     def safety():  # noqa: WPS430
         packages = list(read_requirements(StringIO(requirements)))
-        vulns = safety_check(packages=packages, ignore_ids="", key="", db_mirror="", cached=False, proxy={})
-        output_report = report(vulns=vulns, full=True, checked_packages=len(packages))
+        vulns, db_full = safety_check(packages=packages, ignore_vulns="")
+        remediations = calculate_remediations(vulns, db_full)
+        output_report = SafetyFormatter("text").render_vulnerabilities(
+            announcements=[],
+            vulnerabilities=vulns,
+            remediations=remediations,
+            full=True,
+            packages=packages,
+        )
         if vulns:
             print(output_report)
+            return False
+        return True
 
     ctx.run(safety, title="Checking dependencies")
 
@@ -181,49 +189,7 @@ def check_types(ctx):  # noqa: WPS231
     Arguments:
         ctx: The context instance (passed automatically).
     """
-    # NOTE: the following code works around this issue:
-    # https://github.com/python/mypy/issues/10633
-
-    # compute packages directory path
-    py = f"{sys.version_info.major}.{sys.version_info.minor}"
-    pkgs_dir = Path("__pypackages__", py, "lib").resolve()
-
-    # build the list of available packages
-    packages = {}
-    for package in pkgs_dir.glob("*"):
-        if package.suffix not in {".dist-info", ".pth"} and package.name != "__pycache__":
-            packages[package.name] = package
-
-    # handle .pth files
-    for pth in pkgs_dir.glob("*.pth"):
-        with suppress(OSError):
-            for package in Path(pth.read_text().splitlines()[0]).glob("*"):  # noqa: WPS440
-                if package.suffix != ".dist-info":
-                    packages[package.name] = package
-
-    # create a temporary directory to assign to MYPYPATH
-    with tempfile.TemporaryDirectory() as tmpdir:
-
-        # symlink the stubs
-        ignore = set()
-        for stubs in (path for name, path in packages.items() if name.endswith("-stubs")):  # noqa: WPS335
-            Path(tmpdir, stubs.name).symlink_to(stubs, target_is_directory=True)
-            # try to symlink the corresponding package
-            # see https://www.python.org/dev/peps/pep-0561/#stub-only-packages
-            pkg_name = stubs.name.replace("-stubs", "")
-            if pkg_name in packages:
-                ignore.add(pkg_name)
-                Path(tmpdir, pkg_name).symlink_to(packages[pkg_name], target_is_directory=True)
-
-        # create temporary mypy config to ignore stubbed packages
-        newconfig = Path("config", "mypy.ini").read_text()
-        newconfig += "\n" + "\n\n".join(f"[mypy-{pkg}.*]\nignore_errors=true" for pkg in ignore)
-        tmpconfig = Path(tmpdir, "mypy.ini")
-        tmpconfig.write_text(newconfig)
-
-        # set MYPYPATH and run mypy
-        os.environ["MYPYPATH"] = tmpdir
-        ctx.run(f"mypy --config-file {tmpconfig} {PY_SRC}", title="Type-checking", pty=PTY)
+    ctx.run(f"mypy --config-file config/mypy.ini {PY_SRC}", title="Type-checking", pty=PTY)
 
 
 @duty(silent=True)
