@@ -21,10 +21,10 @@ instruction:
       option_x: etc
 ```
 """
+import functools
 import re
 from collections import ChainMap
 from typing import Any, MutableSequence, Tuple
-from warnings import warn
 from xml.etree.ElementTree import Element
 
 import yaml
@@ -127,17 +127,18 @@ class AutoDocProcessor(BlockProcessor):
             el.extend(headings)
 
             page = self._autorefs.current_page
-            for heading in headings:
-                anchor = heading.attrib["id"]  # noqa: WPS440
-                self._autorefs.register_anchor(page, anchor)  # noqa: WPS441
+            if page:
+                for heading in headings:
+                    anchor = heading.attrib["id"]  # noqa: WPS440
+                    self._autorefs.register_anchor(page, anchor)  # noqa: WPS441
 
-                if "data-role" in heading.attrib:
-                    self._handlers.inventory.register(
-                        name=anchor,  # noqa: WPS441
-                        domain=handler.domain,
-                        role=heading.attrib["data-role"],
-                        uri=f"{page}#{anchor}",  # noqa: WPS441
-                    )
+                    if "data-role" in heading.attrib:
+                        self._handlers.inventory.register(
+                            name=anchor,  # noqa: WPS441
+                            domain=handler.domain,
+                            role=heading.attrib["data-role"],
+                            uri=f"{page}#{anchor}",  # noqa: WPS441
+                        )
 
             parent.append(el)
 
@@ -182,10 +183,7 @@ class AutoDocProcessor(BlockProcessor):
         options = ChainMap(local_options, deprecated_local_options, global_options, deprecated_global_options)
 
         if deprecated_global_options or deprecated_local_options:
-            warn(
-                "'selection' and 'rendering' are deprecated and merged into a single 'options' YAML key",
-                DeprecationWarning,
-            )
+            self._warn_about_options_key()
 
         if heading_level:
             options = ChainMap(options, {"heading_level": heading_level})  # like setdefault
@@ -216,6 +214,11 @@ class AutoDocProcessor(BlockProcessor):
 
         return rendered, handler, data
 
+    @classmethod
+    @functools.lru_cache(maxsize=None)  # Warn only once
+    def _warn_about_options_key(cls):
+        log.info("DEPRECATION: 'selection' and 'rendering' are deprecated and merged into a single 'options' YAML key")
+
 
 class _PostProcessor(Treeprocessor):
     def run(self, root: Element):
