@@ -19,7 +19,6 @@ import os
 from concurrent import futures
 from typing import Any, BinaryIO, Callable, Iterable, List, Mapping, Optional, Tuple
 from urllib import request
-from warnings import warn
 
 from mkdocs.config import Config
 from mkdocs.config.config_options import Type as MkType
@@ -112,7 +111,9 @@ class MkdocstringsPlugin(BasePlugin):
         return self._handlers
 
     # TODO: remove once watch feature is removed
-    def on_serve(self, server: LiveReloadServer, builder: Callable, **kwargs: Any):  # noqa: W0613 (unused arguments)
+    def on_serve(
+        self, server: LiveReloadServer, config: Config, builder: Callable, *args: Any, **kwargs: Any
+    ) -> None:  # noqa: W0613 (unused arguments)
         """Watch directories.
 
         Hook for the [`on_serve` event](https://www.mkdocs.org/user-guide/plugins/#on_serve).
@@ -122,15 +123,12 @@ class MkdocstringsPlugin(BasePlugin):
 
         Arguments:
             server: The `livereload` server instance.
+            config: The MkDocs config object (unused).
             builder: The function to build the site.
+            *args: Additional arguments passed by MkDocs.
             **kwargs: Additional arguments passed by MkDocs.
         """
         if self.config["watch"]:
-            warn(
-                "mkdocstrings' watch feature is deprecated in favor of MkDocs' watch feature, "
-                "see https://www.mkdocs.org/user-guide/configuration/#watch.",
-                DeprecationWarning,
-            )
             for element in self.config["watch"]:
                 log.debug(f"Adding directory '{element}' to watcher")
                 server.watch(element, builder)
@@ -205,6 +203,9 @@ class MkdocstringsPlugin(BasePlugin):
                 self._inv_futures.append(future)
             inv_loader.shutdown(wait=False)
 
+        if self.config["watch"]:
+            self._warn_about_watch_option()
+
         return config
 
     @property
@@ -219,7 +220,7 @@ class MkdocstringsPlugin(BasePlugin):
             inventory_enabled = any(handler.enable_inventory for handler in self.handlers.seen_handlers)
         return inventory_enabled
 
-    def on_env(self, env, config: Config, **kwargs):
+    def on_env(self, env, config: Config, *args, **kwargs) -> None:
         """Extra actions that need to happen after all Markdown rendering and before HTML rendering.
 
         Hook for the [`on_env` event](https://www.mkdocs.org/user-guide/plugins/#on_env).
@@ -299,3 +300,11 @@ class MkdocstringsPlugin(BasePlugin):
             result = dict(loader(content, url=url, **kwargs))
         log.debug(f"Loaded inventory from {url!r}: {len(result)} items")
         return result
+
+    @classmethod
+    @functools.lru_cache(maxsize=None)  # Warn only once
+    def _warn_about_watch_option(cls):
+        log.info(
+            "DEPRECATION: mkdocstrings' watch feature is deprecated in favor of MkDocs' watch feature, "
+            "see https://www.mkdocs.org/user-guide/configuration/#watch",
+        )
